@@ -385,9 +385,9 @@ reservedIPs = '240.0.0.0/4'
 unspecifiedIPs = {'0.0.0.0', '::'}
 linkLocalIPs = {'169.254.0.0/16', 'fe80::/10'}
 loopBackIPs = {'127.0.0.0/8', '::1'}
-ipv4Mapped = "::ffff:0:0/96"
-ipv4Translated = "::ffff:0:0:0/96"
-ipv4ipv6Translated = '64:ff9b::/96'
-teredo = '2001::/32'
-sixToFour = '2002::/16'
-siteLocal = 'fc00::/7'
+ipv4MappedIPs = "::ffff:0:0/96"
+ipv4TranslatedIPs = "::ffff:0:0:0/96"
+ipv4ipv6TranslatedIPs = '64:ff9b::/96'
+teredoIPs = '2001::/32'
+sixToFourIPs = '2002::/16'
+siteLocalIPs = 'fc00::/7'
